@@ -10,7 +10,7 @@ class ImmutableList(tuple):
         self.warning = warning
         return self
 
-    def complain(self, *wargs, **kwargs):
+    def complain(self, *args, **kwargs):
         if isinstance(self.warning, Exception):
             raise self.warning
         else:
@@ -38,3 +38,21 @@ class ImmutableDict(dict):
         raise ValueError("Read Only dict proxy")
 
     popitem = update = clear = pop = __setitem__ = __delitem__ = NotImplementedError
+
+
+class __ImmutablePropertyClassMeta(type):
+    ''' 元类, 限定类属性不可被修改 '''
+
+    def __init__(cls, classname, bases, dict_, **kw):
+
+        type.__init__(cls, classname, bases, dict_)
+
+    def __setattr__(cls, *_):
+        raise TypeError(f"{cls.__class__.__name__} 不支持修改属性")
+
+    def __setattribute__(cls, *_):
+        raise TypeError(f"{cls.__class__.__name__} 不支持修改属性")
+
+
+# 可以通过继承这个类限定类属性定义后不可被更改
+ImmutablePropertyClassBase = __ImmutablePropertyClassMeta("ImmutablePropertyClassBase", (object, ), {})
